package com.ruoyi.web.controller.warehouse.warehouseBusiness;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.ServletUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.utils.spring.SpringUtils;
import com.ruoyi.framework.web.service.TokenService;
import com.ruoyi.warehouseBusiness.domain.TWarehouseBills;
import com.ruoyi.warehouseBusiness.domain.dto.WarehousebillsDTO;
import com.ruoyi.warehouseBusiness.domain.enums.WarehouseTypeEnum;
import com.ruoyi.warehouseBusiness.excel.GoodsTransfer;
import com.ruoyi.warehouseBusiness.service.ITWarehouseBillsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * 仓储货转Controller
 *
 * @author ruoyi
 * @date 2020-12-29
 */
@RestController
@RequestMapping("/warehouseBusiness/goodsTransfer")
public class TWarehouseGoodsTransferController extends BaseController {
    @Autowired
    private ITWarehouseBillsService itWarehouseBillsService;

    /**
     * 查询货转详情主表列表
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:list')")
    @DataScope(deptAlias = "d", userAlias = "u")
    @GetMapping("/list")
    public TableDataInfo list(TWarehouseBills tWarehouseBills) {
        startPage();
        tWarehouseBills.setfBilltype("HQZY");
        List<Map<String, Object>> list = itWarehouseBillsService.selectWarehouseBusinessList(tWarehouseBills);
        return getDataTable(list);
    }


    /**
     * 导出货转详情主表列表
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:export')")
    @Log(title = "详情主表", businessType = BusinessType.EXPORT)
    @DataScope(deptAlias = "d", userAlias = "u")
    @GetMapping("/export")
    @RepeatSubmit
    public AjaxResult export(TWarehouseBills tWarehouseBills) throws Exception {
        tWarehouseBills.setfBilltype("HQZY");
        List<GoodsTransfer> list = itWarehouseBillsService.goodsTransferExport(tWarehouseBills);
        ExcelUtil<GoodsTransfer> util = new ExcelUtil<GoodsTransfer>(GoodsTransfer.class);
        return util.exportExcel(list, "货转");
    }

    /**
     * 获取货转仓库详细信息
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:query')")
    @GetMapping(value = "/{fId}")
    @RepeatSubmit
    public AjaxResult getInfo(@PathVariable("fId") Long fId) {
        return AjaxResult.success(itWarehouseBillsService.selectTWarehousebillsById(fId));
    }

    /**
     * 货转暂存
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:add')")
    @Log(title = "详情主表", businessType = BusinessType.INSERT)
    @PostMapping(value = "/add")
    @RepeatSubmit
    public AjaxResult add(@RequestParam("warehouseBills") String tWarehouseBills,
                          @RequestParam("tEnclosure") String tWhgenleg,
                          @RequestParam("tCntr") String tCntr,
                          @RequestParam("warehousebillsfeesCr") String tWarehousebillsfeesCr,
                          @RequestParam("warehousebillsfeesDr") String tWarehousebillsfeesDr,
                          @RequestParam("warehousebillsitems") String tWarehousebillsitems,
                          @RequestParam("mblnoStatus") String mblnoStatus) {
        String billsType = "HQZY";
        if (StringUtils.isEmpty(tWarehouseBills) || "{}".equals(tWarehouseBills)) {
            return AjaxResult.error("提交失败：请检查主表数据");
        }
        /*if (StringUtils.isEmpty(tWarehousebillsitems) || "[]".equals(tWarehousebillsitems)) {
            return AjaxResult.error("提交失败：请检查库存明细数据");
        }*/
        if (StringUtils.isEmpty(mblnoStatus)) {
            // 判断是提单号是否在一天当中出现第二次或以上
            AjaxResult result = itWarehouseBillsService.selectContainMblno(tWarehouseBills, billsType);
            String ajaxCode = result.get("code").toString();
            if ("500".equals(ajaxCode)) {
                return result;
            }
        }
        // 获取当前的用户
        LoginUser loginUser = SpringUtils.getBean(TokenService.class).getLoginUser(ServletUtils.getRequest());
        return itWarehouseBillsService.insertTWarehousebills(tWarehouseBills, tWarehousebillsfeesCr,
                tWarehousebillsfeesDr, tWarehousebillsitems, tWhgenleg, loginUser, tCntr, billsType);
    }

    /**
     * 货转提交
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:inStock:add')")
    @Log(title = "详情主表", businessType = BusinessType.INSERT)
    @PostMapping(value = "/warehouseSubmission")
    @RepeatSubmit
    public AjaxResult warehouseSubmission(@RequestParam("warehouseBills") String tWarehouseBills,
                                          @RequestParam("tEnclosure") String tEnclosure,
                                          @RequestParam("tCntr") String tCntr,
                                          @RequestParam("warehousebillsfeesCr") String tWarehousebillsfeesCr,
                                          @RequestParam("warehousebillsfeesDr") String tWarehousebillsfeesDr,
                                          @RequestParam("warehousebillsitems") String tWarehousebillsitems) {
        String billsType = "HQZY";
        if (StringUtils.isNull(tWarehouseBills) || "{}".equals(tWarehouseBills)) {
            return AjaxResult.error("未找到仓库主表数据，请确认");
        }
        /*if (StringUtils.isNull(tWarehousebillsitems) || "[]".equals(tWarehousebillsitems)) {
            return AjaxResult.error("未找到仓库明细数据，请确认");
        }*/
        LoginUser loginUser = SpringUtils.getBean(TokenService.class).getLoginUser(ServletUtils.getRequest());
        return itWarehouseBillsService.warehouseSubmission(tWarehouseBills, tWarehousebillsfeesCr,
                tWarehousebillsfeesDr, tWarehousebillsitems, tEnclosure, loginUser, tCntr, billsType);
    }

    /**
     * 货转确认
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:inStock:add')")
    @Log(title = "详情主表", businessType = BusinessType.INSERT)
    @PostMapping(value = "/addCredit")
    @RepeatSubmit
    public AjaxResult addCredit(@RequestParam("warehouseBills") String warehouseBills,
                                @RequestParam("tEnclosure") String tEnclosure,
                                @RequestParam("tCntr") String tCntr,
                                @RequestParam("warehousebillsfeesCr") String warehousebillsfeesCr,
                                @RequestParam("warehousebillsfeesDr") String warehousebillsfeesDr,
                                @RequestParam("warehousebillsitems") String warehousebillsitems) {
        String billsType = "HQZY";
        if (StringUtils.isNull(warehouseBills) || "{}".equals(warehouseBills)) {
            return AjaxResult.error("未找到主表信息，请确认");
        }
        if (StringUtils.isNull(warehousebillsitems) || "[]".equals(warehousebillsitems)) {
            return AjaxResult.error("未找到明细信息，请确认");
        }
        // 获取当前的用户
        LoginUser loginUser = SpringUtils.getBean(TokenService.class).getLoginUser(ServletUtils.getRequest());
        return itWarehouseBillsService.updateCredit(warehouseBills, warehousebillsitems, tEnclosure, warehousebillsfeesCr,
                warehousebillsfeesDr, loginUser, tCntr, billsType);
    }

    /**
     * 修改货转详情主表
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:edit')")
    @Log(title = "详情主表", businessType = BusinessType.UPDATE)
    @PutMapping
    @RepeatSubmit
    public AjaxResult edit(@RequestBody TWarehouseBills tWarehouseBills) {
        return toAjax(itWarehouseBillsService.updateTWarehousebills(tWarehouseBills));
    }

    /**
     * 删除货转详情主表
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:remove')")
    @Log(title = "详情主表", businessType = BusinessType.DELETE)
    @DeleteMapping("/{fIds}")
    @RepeatSubmit
    public AjaxResult remove(@PathVariable Long[] fIds) {
        return itWarehouseBillsService.deleteTWarehousebillsByIds(fIds);
    }

    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:remove')")
    @Log(title = "详情主表", businessType = BusinessType.DELETE)
    @DeleteMapping("/queryRemove/{fId}")
    public AjaxResult queryRemove(@PathVariable("fId") Long fId) {
        return itWarehouseBillsService.queryRemove(fId);
    }

    /**
     * 撤销入库信息
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:revoke')")
    @Log(title = "详情主表", businessType = BusinessType.UPDATE)
    @GetMapping("/withdrawById/{fId}")
    @RepeatSubmit
    public AjaxResult withdrawById(@PathVariable("fId") Long fId) {
        // 查询是否对账、收费、付费
        int result = itWarehouseBillsService.derecognition(fId);
        if (result == 1) {
            return AjaxResult.error("撤销请核失败，财务已对账");
        } else if (result == 2) {
            return AjaxResult.error("撤销请核失败，财务已收费");
        } else if (result == 3) {
            return AjaxResult.error("撤销请核失败，财务已付费");
        }
        String billsType = "HQZYRevoke";
        // 获取当前的用户
        LoginUser loginUser = SpringUtils.getBean(TokenService.class).getLoginUser(ServletUtils.getRequest());
        return itWarehouseBillsService.revokeTWarehousebillsById(fId, loginUser, billsType);
    }

    /**
     * 撤销货转
     */
    @PreAuthorize("@ss.hasPermi('warehouseBusiness:goodsTransfer:add')")
    @Log(title = "详情主表", businessType = BusinessType.INSERT)
    @PostMapping(value = "/updateCredit")
    @RepeatSubmit
    public AjaxResult deleteCredit(@RequestParam("warehouseBills") String warehouseBills,
                                   @RequestParam("tEnclosure") String tEnclosure,
                                   @RequestParam("tCntr") String tCntr,
                                   @RequestParam("warehousebillsfeesCr") String warehousebillsfeesCr,
                                   @RequestParam("warehousebillsfeesDr") String warehousebillsfeesDr,
                                   @RequestParam("warehousebillsitems") String warehousebillsitems) {
        String billsType = "HQZYRevoke";
        // 获取当前的用户
        LoginUser loginUser = SpringUtils.getBean(TokenService.class).getLoginUser(ServletUtils.getRequest());
        return itWarehouseBillsService.revokeTWarehousebillsById1(warehouseBills, warehousebillsitems,
                tEnclosure, warehousebillsfeesCr, warehousebillsfeesDr, loginUser, tCntr, billsType);
    }

    /**
     * 货转根据条件查询可用客户、仓库信息
     */
    @DataScope(deptAlias = "d", userAlias = "u")
    @PostMapping(value = "/corpOrWarehouseByMblno")
    public AjaxResult corpOrWarehouseByMblno(@RequestBody WarehousebillsDTO warehousebillsDTO) {
        // 判断是否传入值
        if (StringUtils.isNull(warehousebillsDTO) || StringUtils.isEmpty(warehousebillsDTO.getfMblno())) {
            return AjaxResult.error("未找到提单号");
        }
        return itWarehouseBillsService.corpOrWarehouseByMblno(warehousebillsDTO);
    }

    /**
     * 根据id更新费用审核状态
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/feeReview")
    @RepeatSubmit
    public AjaxResult feeReviewSubmit(@RequestParam("id") Long id) {
        return itWarehouseBillsService.feeReviewSubmit(id);
    }

    /**
     * 根据id撤销已费用审核状态
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/revokefeeReview")
    @RepeatSubmit
    public AjaxResult revokefeeReview(@RequestParam("id") Long id) {
        return itWarehouseBillsService.revokefeeReview(id);
    }

    /**
     * app查货转详情
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/app")
    @RepeatSubmit
    public AjaxResult appQueryInit(@RequestParam("id") Long id) {
        return itWarehouseBillsService.appQueryInit(id, WarehouseTypeEnum.HQZY.getType());
    }

}
